==> dl.php?src=linea21_2_3_0.zip: linea21/languages/es/lang_page.utf-8.php <==
<?php
/**
 * @package linea21\languages\es
 * @author $Author$ - Raul Agraz, Simon Georget <simon@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['page']['section'] = "páginas";

/*	nommage des modules
 *  	*/
$lang['page']['name']='página';
$lang['page']['confirm_add'] = "Página agregada correctamente\n";
$lang['page']['confirm_mod'] = "Página actualizada correctamente\n";
$lang['page']['confirm_sup'] ="Página eliminada correctamente\n";


/*	nommage rubrique module
 *  	*/
$lang['page']['add']= 'Agregar nueva '.$lang['page']['name'];
$lang['page']['mod']= 'Editar '.$lang['page']['name'];
$lang['page']['sup']= 'Eliminar'.$lang['page']['name'];
$lang['page']['det']= 'Detalles de la '.$lang['page']['name'];
$lang['page']['list']= 'Consulta de las páginas'.$lang['page']['name'];


/*	nommage rubrique add / mod /det
 *  	*/
$lang['page']['add_title']='Ingresar datos de la nueva '.$lang['page']['name'];
$lang['page']['mod_title']='Editar datos de la '.$lang['page']['name'];
$lang['page']['recap_commment']='sin comentarios';


/*	check integrité des données
 *  	*/
$lang['page']['no_title']='La página requiere un título';
$lang['page']['no_body']='La página requiere un contenido';
$lang['page']['no_header']='La página requiere un resumen';



/*	nommage élément rubrique
 *  	*/
$lang['page']['title']='Título';
$lang['page']['header']= 'encabezado';
$lang['page']['body']= 'contenido';
$lang['page']['public-url']= 'URL público';
$lang['page']['is_homepage']='página de inicio';
$lang['page']['statut']='estado de la publicación';
$lang['page']['author']='autor';



/*	nommage quickbox
 *  	*/
$lang['page']['qb_titleadd']=' Últimas adiciones';
$lang['page']['qb_titlemod']=' Últimas modificaciones';
$lang['page']['qb_titlesup']=' Últimas supresiones';
$lang['page']['qb_titlepubli']=' Últimas publicaciones';


/*	divers
 *  	*/
$lang['page']['nb_total']='las páginas son almacenadas en la base de datos.';
$lang['page']['statut_filter']='Mostrar por estado';
$lang['page']['all']='Mostrar la lista completa';
$lang['page']['noresult']='Ninguna página corresponde con el criterio de selección ';


/*	public
 *  	*/
$lang['page']['name2']='página(s)';

/*	rubrique d'aide
 *  	*/
$lang['page']['help_add1']='Para agregar una página, ingrese los datos requeridos en el formulario siguiente';
$lang['page']['help_add2']='Después de validar el formulario de adición, verifique los datos ingresados en el resumen';
$lang['page']['help_add3']='Si el resumen no le convence, puede hacer clic en \'revisar ajustes\' para modificar de nuevo los datos';


$lang['page']['help_list1']='Para mostrar una página a detalle, haga clic sobre el título';
$lang['page']['help_list2']='Puede eliminar la página al hacer clic en el icono de supresión asociado';
$lang['page']['help_list3']='Puede editar la página al hacer clic en el icono de edición asociado';
$lang['page']['help_list4']='Puede usar el filtro \'por estatus\' para mostrar las páginas deseadas';
$lang['page']['help_list5']='Para agregar una página, haga clic en \'agregar página\' en la barra de título';
$lang['page']['help_list6']='Puede realizar una búsqueda avanzada en todo momento al hacer clic en \'búsqueda\'';


$lang['page']['help_mod1']='Puede modificar el conjunto de campos que le son accesibles en el siguiente formulario';
$lang['page']['help_mod2']='Después de validar el formulario de modificación, verifique los datos ingresados en el resumen';
$lang['page']['help_mod3']='Si el resumen no le convence, puede hacer clic en \'revisar ajustes\' para modificar de nuevo los datos';


$lang['page']['help_det1']='Puede eliminar la página al hacer clic en el icono de supresión asociado';
$lang['page']['help_det2']='Puede editar la página al hacer clic en el icono de edición asociado';

$lang['page']['help_sup1']='Si usted no quiere continuar con la supresión de la página en curso, haga clic en \'Anular\'';
?>

==> dl.php?src=linea21_2_5_0.zip: linea21/languages/es/lang_page.utf-8.php <==
<?php
/**
 * @package linea21\languages\es
 * @author $Author$ - Raul Agraz, Simon Georget <simon@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['page']['section'] = "páginas";

/*	nommage des modules
 *  	*/
$lang['page']['name']='página';
$lang['page']['confirm_add'] = "Página agregada correctamente\n";
$lang['page']['confirm_mod'] = "Página actualizada correctamente\n";
$lang['page']['confirm_sup'] ="Página eliminada correctamente\n";


/*	nommage rubrique module
 *  	*/
$lang['page']['add']= 'Agregar nueva '.$lang['page']['name'];
$lang['page']['mod']= 'Editar '.$lang['page']['name'];
$lang['page']['sup']= 'Eliminar'.$lang['page']['name'];
$lang['page']['det']= 'Detalles de la '.$lang['page']['name'];
$lang['page']['list']= 'Consulta de las páginas'.$lang['page']['name'];


/*	nommage rubrique add / mod /det
 *  	*/
$lang['page']['add_title']='Ingresar datos de la nueva '.$lang['page']['name'];
$lang['page']['mod_title']='Editar datos de la '.$lang['page']['name'];
$lang['page']['recap_commment']='sin comentarios';


/*	check integrité des données
 *  	*/
$lang['page']['no_title']='La página requiere un título';
$lang['page']['no_body']='La página requiere un contenido';
$lang['page']['no_header']='La página requiere un resumen';



/*	nommage élément rubrique
 *  	*/
$lang['page']['title']='Título';
$lang['page']['header']= 'encabezado';
$lang['page']['body']= 'contenido';
$lang['page']['heading']= 'heading'; // @todo translation
$lang['page']['heading_info']= 'heading text for given element'; // @todo translation
$lang['page']['public-url']= 'URL público';
$lang['page']['is_homepage']='página de inicio';
$lang['page']['statut']='estado de la publicación';
$lang['page']['author']='autor';



/*	nommage quickbox
 *  	*/
$lang['page']['qb_titleadd']=' Últimas adiciones';
$lang['page']['qb_titlemod']=' Últimas modificaciones';
$lang['page']['qb_titlesup']=' Últimas supresiones';
$lang['page']['qb_titlepubli']=' Últimas publicaciones';


/*	divers
 *  	*/
$lang['page']['nb_total']='las páginas son almacenadas en la base de datos.';
$lang['page']['statut_filter']='Mostrar por estado';
$lang['page']['all']='Mostrar la lista completa';
$lang['page']['noresult']='Ninguna página corresponde con el criterio de selección ';


/*	public
 *  	*/
$lang['page']['name2']='página(s)';

/*	rubrique d'aide
 *  	*/
$lang['page']['help_add1']='Para agregar una página, ingrese los datos requeridos en el formulario siguiente';
$lang['page']['help_add2']='Después de validar el formulario de adición, verifique los datos ingresados en el resumen';
$lang['page']['help_add3']='Si el resumen no le convence, puede hacer clic en \'revisar ajustes\' para modificar de nuevo los datos';


$lang['page']['help_list1']='Para mostrar una página a detalle, haga clic sobre el título';
$lang['page']['help_list2']='Puede eliminar la página al hacer clic en el icono de supresión asociado';
$lang['page']['help_list3']='Puede editar la página al hacer clic en el icono de edición asociado';
$lang['page']['help_list4']='Puede usar el filtro \'por estatus\' para mostrar las páginas deseadas';
$lang['page']['help_list5']='Para agregar una página, haga clic en \'agregar página\' en la barra de título';
$lang['page']['help_list6']='Puede realizar una búsqueda avanzada en todo momento al hacer clic en \'búsqueda\'';


$lang['page']['help_mod1']='Puede modificar el conjunto de campos que le son accesibles en el siguiente formulario';
$lang['page']['help_mod2']='Después de validar el formulario de modificación, verifique los datos ingresados en el resumen';
$lang['page']['help_mod3']='Si el resumen no le convence, puede hacer clic en \'revisar ajustes\' para modificar de nuevo los datos';


$lang['page']['help_det1']='Puede eliminar la página al hacer clic en el icono de supresión asociado';
$lang['page']['help_det2']='Puede editar la página al hacer clic en el icono de edición asociado';

$lang['page']['help_sup1']='Si usted no quiere continuar con la supresión de la página en curso, haga clic en \'Anular\'';
?>
